@@ -22,17 +22,21 @@
 
 define(
     [
-        'angular',
-        'angular-sanitize',
-        'repositories/models'
+      'angular',
+      'angular-sanitize',
+      'repositories/models',
+      'repositories/services'
     ],
 
   function(angular) {
 
     var repoConnectionAppControllers = angular.module('repoConnectionAppControllers', []);
 
-    repoConnectionAppControllers.controller("PentahoRepositoryController", function($scope, $translate, $location, $rootScope, $timeout, $filter, pentahoRepositoryModel, repositoryTypesModel, loadingAnimationModel) {
+    repoConnectionAppControllers.controller("PentahoRepositoryController", function($scope, $translate, $location, $rootScope, $timeout, $filter, pentahoRepositoryModel, repositoryTypesModel, loadingAnimationModel, repositoriesService) {
       $scope.model = pentahoRepositoryModel.model;
+      $rootScope.fromConnect = false;
+      var connectedRepositoryName = getConnectedRepositoryName();
+      $rootScope.connectNowVisible = !($rootScope.fromEdit && connectedRepositoryName === pentahoRepositoryModel.model.displayName);
       $scope.getStarted = function() {
         $rootScope.fromEdit = false;
         pentahoRepositoryModel.reset();
@@ -76,15 +80,17 @@ define(
         }
         loadingAnimationModel.displayName = this.model.displayName;
         $timeout(function(){
-          if (createRepository("PentahoEnterpriseRepository", JSON.stringify($scope.model))) {
+          repositoriesService.add( $scope.model ).
+          then(function(response) {
             $location.path("/pentaho-repository-creation-success");
-          } else {
+            if($scope.model.isDefault) {
+              setDefaultRepository($scope.model.displayName);
+            }
+            $rootScope.next();
+          }, function (response) {
             $location.path("/pentaho-repository-creation-failure");
-          }
-          if($scope.model.isDefault) {
-            setDefaultRepository($scope.model.displayName);
-          }
-          $rootScope.next();
+            $rootScope.next();
+          });
         },1000);
         $location.path("/loading-animation");
         $rootScope.next();
@@ -107,7 +113,8 @@ define(
       }
       $scope.back = function() {
         $rootScope.clearError();
-        if (this.model.id) {
+        if ($rootScope.fromEdit) {
+          $rootScope.fromEdit = false;
           $location.path("/repository-manager");
         } else {
           $location.path("/pentaho-repository");
@@ -122,9 +129,11 @@ define(
       }
     });
 
-    repoConnectionAppControllers.controller("KettleFileRepositoryController", function($scope, $translate, $rootScope, $location, $filter, kettleFileRepositoryModel) {
-
+    repoConnectionAppControllers.controller("KettleFileRepositoryController", function($scope, $translate, $rootScope, $location, $filter, kettleFileRepositoryModel, repositoriesService) {
       $scope.model = kettleFileRepositoryModel.model;
+      $rootScope.fromConnect = false;
+      var connectedRepositoryName = getConnectedRepositoryName();
+      $rootScope.connectNowVisible = !($rootScope.fromEdit && connectedRepositoryName === kettleFileRepositoryModel.model.displayName);
       $scope.selectLocation = function() {
         this.model.location = selectLocation();
       }
@@ -159,15 +168,17 @@ define(
             return;
           }
         }
-        if (createRepository("KettleFileRepository", JSON.stringify(this.model))) {
+        repositoriesService.add( $scope.model ).
+        then(function(response) {
           $location.path("/kettle-file-repository-creation-success");
-        } else {
+          if($scope.model.isDefault) {
+            setDefaultRepository($scope.model.displayName);
+          }
+          $rootScope.next();
+        }, function (response) {
           $location.path("/kettle-file-repository-creation-failure");
-        }
-        if(this.model.isDefault) {
-          setDefaultRepository(this.model.displayName);
-        }
-        $rootScope.next();
+          $rootScope.next();
+        });
       }
       $scope.createNewConnection = function() {
         $location.path("/repository-manager");
@@ -192,7 +203,8 @@ define(
       }
       $scope.back = function() {
         $rootScope.clearError();
-        if (this.model.id) {
+        if ($rootScope.fromEdit) {
+          $rootScope.fromEdit = false;
           $location.path("/repository-manager");
         } else {
           $location.path("/create-new-connection");
@@ -207,8 +219,11 @@ define(
       }
     });
 
-    repoConnectionAppControllers.controller("KettleDatabaseRepositoryController", function($scope, $rootScope, $location, $timeout, $filter, kettleDatabaseRepositoryModel, loadingAnimationModel) {
+    repoConnectionAppControllers.controller("KettleDatabaseRepositoryController", function($scope, $rootScope, $location, $timeout, $filter, kettleDatabaseRepositoryModel, loadingAnimationModel, repositoriesService) {
       $scope.model = kettleDatabaseRepositoryModel.model;
+      $rootScope.fromConnect = false;
+      var connectedRepositoryName = getConnectedRepositoryName();
+      $rootScope.connectNowVisible = !($rootScope.fromEdit && connectedRepositoryName === kettleDatabaseRepositoryModel.model.displayName);
       $scope.selectDatabase = function() {
         $rootScope.clearError();
         $location.path("/kettle-database-repository-select");
@@ -247,15 +262,17 @@ define(
         }
         loadingAnimationModel.displayName = this.model.displayName;
         $timeout(function(){
-          if (createRepository("KettleDatabaseRepository", JSON.stringify($scope.model))) {
+          repositoriesService.add( $scope.model ).
+          then(function(response) {
             $location.path("/kettle-database-repository-creation-success");
-          } else {
+            if($scope.model.isDefault) {
+              setDefaultRepository($scope.model.displayName);
+            }
+            $rootScope.next();
+          }, function (response) {
             $location.path("/kettle-database-repository-creation-failure");
-          }
-          if($scope.model.isDefault) {
-            setDefaultRepository($scope.model.displayName);
-          }
-          $rootScope.next();
+            $rootScope.next();
+          });
         },1000);
         $location.path("/loading-animation");
         $rootScope.next();
@@ -278,7 +295,8 @@ define(
       }
       $scope.back = function() {
         $rootScope.clearError();
-        if (this.model.id) {
+        if ($rootScope.fromEdit) {
+          $rootScope.fromEdit = false;
           $location.path("/repository-manager");
         } else {
           $location.path("/create-new-connection");
@@ -383,10 +401,15 @@ define(
       repositoriesModel.repositories = JSON.parse(getRepositories());
       repositoriesModel.selectedRepository = null;
       $scope.model = repositoriesModel;
+      var clickedDefault = false;
       $scope.selectRepository = function(repository) {
-        repositoriesModel.selectedRepository = repository;
+        if(!clickedDefault) {
+          repositoriesModel.selectedRepository = repositoriesModel.selectedRepository == repository ? null : repository;
+        }
+        clickedDefault = false;
       }
       $scope.setDefault = function(repository) {
+        clickedDefault = true;
         var name = repository != null ? repository.displayName : null;
         setDefaultRepository(name);
         for ( i = 0; i < repositoriesModel.repositories.length; i++) {
@@ -396,7 +419,6 @@ define(
             repositoriesModel.repositories[i].isDefault = false;
           }
         }
-        repositoriesModel.selectedRepository = repository;
       }
       $scope.edit = function(repository) {
         $rootScope.fromEdit = true;
@@ -421,6 +443,7 @@ define(
             this.model.repositories.splice(i, 1);
           }
         }
+        repositoriesModel.selectedRepository = null;
       }
       $scope.add = function() {
         $location.path("/pentaho-repository");
@@ -435,10 +458,11 @@ define(
       $scope.addToolTips = addToolTips;
     });
 
-    repoConnectionAppControllers.controller("RepositoryConnectController", function($scope, $rootScope, $location, $timeout, repositoryConnectModel, loadingAnimationModel) {
+    repoConnectionAppControllers.controller("RepositoryConnectController", function($scope, $rootScope, $location, $timeout, repositoryConnectModel, loadingAnimationModel, repositoriesService) {
       $scope.model = repositoryConnectModel;
       $scope.model.username = getCurrentUser();
       $scope.model.currentRepositoryName = getCurrentRepository();
+      $rootScope.fromConnect = true;
       $scope.canConnect = function() {
         if (this.model.username == "" || this.model.password == "") {
           return false;
@@ -455,16 +479,18 @@ define(
         }
         loadingAnimationModel.displayName = this.model.currentRepositoryName;
         $timeout(function(){
-          var response = JSON.parse(loginToRepository($scope.model.username, $scope.model.password));
-          if( response.success == false){
+          repositoriesService.login( $scope.model.username, $scope.model.password ).
+          then(function(response) {
+            console.log(response);
+            close();
+          }, function (response) {
+            console.log(response);
             $timeout(function(){
-              $rootScope.triggerError(response.errorMessage);
+              $rootScope.triggerError(response.data.message);
             },600);
             $location.path("/repository-connect");
             $rootScope.backFade();
-          } else {
-            close();
-          }
+          });
         },1000);
         $location.path("/loading-animation");
         $rootScope.nextFade();
